==> spring-boot-starter-warcar-ip-2.3.8.2-sources.jar: com/bxm/warcar/ip/autoconfigure/IpLibraryConfiguration.java <==
package com.bxm.warcar.ip.autoconfigure;

import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 *
 * @author allen
 * @since V1.0.0 2017/12/14
 */
@ConfigurationProperties(prefix = "warcar.ip")
public class IpLibraryConfiguration {

    public static final String USE_TYPE_REMOTE = "remote";
    public static final String USE_TYPE_LOCALFILE = "localfile";

    private boolean baiduEnable = false;

    private boolean ipipNetEnable = false;
    private String ipipNetFingerprintUrl = "http://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipipnet.fingerprint";
    private String ipipNetDataUrl = "https://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipipnet.ipdb";
    private String ipipNetFilePath = "ipipnet.ipdb";
    private String ipipNetUseType = USE_TYPE_REMOTE;

    private boolean ipplus360Enable = false;
    private String ipplus360FingerprintUrl = "http://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipplus360.fingerprint";
    private String ipplus360DataUrl = "http://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipplus360.dat";
    private String ipplus360FilePath = "ipplus360.dat";
    private String ipplus360UseType = USE_TYPE_REMOTE;

    private boolean aliyunEnable = false;
    private String aliyunRegionId = "cn-hangzhou";
    private String aliyunAccessKeyId = "accessKeyId";
    private String aliyunSecret = "secret";
    private String aliyunInstanceId = "instanceId";
    private boolean aliyunAutoUpgrade = true;

    public boolean isBaiduEnable() {
        return baiduEnable;
    }

    public void setBaiduEnable(boolean baiduEnable) {
        this.baiduEnable = baiduEnable;
    }

    public boolean isIpipNetEnable() {
        return ipipNetEnable;
    }

    public void setIpipNetEnable(boolean ipipNetEnable) {
        this.ipipNetEnable = ipipNetEnable;
    }

    public String getIpipNetFilePath() {
        return ipipNetFilePath;
    }

    public void setIpipNetFilePath(String ipipNetFilePath) {
        this.ipipNetFilePath = ipipNetFilePath;
    }

    public String getIpipNetFingerprintUrl() {
        return ipipNetFingerprintUrl;
    }

    public void setIpipNetFingerprintUrl(String ipipNetFingerprintUrl) {
        this.ipipNetFingerprintUrl = ipipNetFingerprintUrl;
    }

    public String getIpipNetDataUrl() {
        return ipipNetDataUrl;
    }

    public void setIpipNetDataUrl(String ipipNetDataUrl) {
        this.ipipNetDataUrl = ipipNetDataUrl;
    }

    public String getIpipNetUseType() {
        return ipipNetUseType;
    }

    public void setIpipNetUseType(String ipipNetUseType) {
        this.ipipNetUseType = ipipNetUseType;
    }

    public boolean isIpplus360Enable() {
        return ipplus360Enable;
    }

    public void setIpplus360Enable(boolean ipplus360Enable) {
        this.ipplus360Enable = ipplus360Enable;
    }

    public String getIpplus360FingerprintUrl() {
        return ipplus360FingerprintUrl;
    }

    public void setIpplus360FingerprintUrl(String ipplus360FingerprintUrl) {
        this.ipplus360FingerprintUrl = ipplus360FingerprintUrl;
    }

    public String getIpplus360DataUrl() {
        return ipplus360DataUrl;
    }

    public void setIpplus360DataUrl(String ipplus360DataUrl) {
        this.ipplus360DataUrl = ipplus360DataUrl;
    }

    public String getIpplus360FilePath() {
        return ipplus360FilePath;
    }

    public void setIpplus360FilePath(String ipplus360FilePath) {
        this.ipplus360FilePath = ipplus360FilePath;
    }

    public String getIpplus360UseType() {
        return ipplus360UseType;
    }

    public void setIpplus360UseType(String ipplus360UseType) {
        this.ipplus360UseType = ipplus360UseType;
    }

    public boolean isAliyunEnable() {
        return aliyunEnable;
    }

    public void setAliyunEnable(boolean aliyunEnable) {
        this.aliyunEnable = aliyunEnable;
    }

    public String getAliyunRegionId() {
        return aliyunRegionId;
    }

    public void setAliyunRegionId(String aliyunRegionId) {
        this.aliyunRegionId = aliyunRegionId;
    }

    public String getAliyunAccessKeyId() {
        return aliyunAccessKeyId;
    }

    public void setAliyunAccessKeyId(String aliyunAccessKeyId) {
        this.aliyunAccessKeyId = aliyunAccessKeyId;
    }

    public String getAliyunSecret() {
        return aliyunSecret;
    }

    public void setAliyunSecret(String aliyunSecret) {
        this.aliyunSecret = aliyunSecret;
    }

    public String getAliyunInstanceId() {
        return aliyunInstanceId;
    }

    public void setAliyunInstanceId(String aliyunInstanceId) {
        this.aliyunInstanceId = aliyunInstanceId;
    }

    public boolean isAliyunAutoUpgrade() {
        return aliyunAutoUpgrade;
    }

    public void setAliyunAutoUpgrade(boolean aliyunAutoUpgrade) {
        this.aliyunAutoUpgrade = aliyunAutoUpgrade;
    }
}

==> spring-boot-starter-warcar-ip-3.0.0.4-sources.jar: com/bxm/warcar/ip/autoconfigure/IpLibraryConfiguration.java <==
package com.bxm.warcar.ip.autoconfigure;

import com.bxm.warcar.ip.impl.aliyun.DataServer;
import com.bxm.warcar.ip.impl.aliyun.OssDataServerImpl;
import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 *
 * @author allen
 * @since V1.0.0 2017/12/14
 */
@ConfigurationProperties(prefix = "warcar.ip")
public class IpLibraryConfiguration {

    public static final String USE_TYPE_REMOTE = "remote";
    public static final String USE_TYPE_LOCALFILE = "localfile";

    private boolean baiduEnable = false;

    private boolean ipipNetEnable = false;
    private String ipipNetFingerprintUrl = "http://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipipnet.fingerprint";
    private String ipipNetDataUrl = "https://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipipnet.ipdb";
    private String ipipNetFilePath = "ipipnet.ipdb";
    private String ipipNetUseType = USE_TYPE_REMOTE;

    private boolean ipplus360Enable = false;
    private String ipplus360FingerprintUrl = "http://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipplus360.fingerprint";
    private String ipplus360DataUrl = "http://bxm-guide.oss-cn-shanghai.aliyuncs.com/dist/IP_File/ipplus360.dat";
    private String ipplus360FilePath = "ipplus360.dat";
    private String ipplus360UseType = USE_TYPE_REMOTE;

    private boolean aliyunEnable = false;
    private boolean aliyunAutoUpgrade = true;
    private Class<? extends DataServer> aliyunDataServer = OssDataServerImpl.class;
    private String aliyunRegionId = "cn-hangzhou";
    private String aliyunAccessKeyId = "accessKeyId";
    private String aliyunSecret = "secret";
    private String aliyunInstanceId = "instanceId";
    private String aliyunOssDataInfoUrl = "https://fcdn.bianxianmao.com/download/ip/aliyun-ip-profile.json";
    private String aliyunOssDownloadUrl = "https://fcdn.bianxianmao.com/download/ip/aliyun-ip-download.json";

    public boolean isBaiduEnable() {
        return baiduEnable;
    }

    public void setBaiduEnable(boolean baiduEnable) {
        this.baiduEnable = baiduEnable;
    }

    public boolean isIpipNetEnable() {
        return ipipNetEnable;
    }

    public void setIpipNetEnable(boolean ipipNetEnable) {
        this.ipipNetEnable = ipipNetEnable;
    }

    public String getIpipNetFilePath() {
        return ipipNetFilePath;
    }

    public void setIpipNetFilePath(String ipipNetFilePath) {
        this.ipipNetFilePath = ipipNetFilePath;
    }

    public String getIpipNetFingerprintUrl() {
        return ipipNetFingerprintUrl;
    }

    public void setIpipNetFingerprintUrl(String ipipNetFingerprintUrl) {
        this.ipipNetFingerprintUrl = ipipNetFingerprintUrl;
    }

    public String getIpipNetDataUrl() {
        return ipipNetDataUrl;
    }

    public void setIpipNetDataUrl(String ipipNetDataUrl) {
        this.ipipNetDataUrl = ipipNetDataUrl;
    }

    public String getIpipNetUseType() {
        return ipipNetUseType;
    }

    public void setIpipNetUseType(String ipipNetUseType) {
        this.ipipNetUseType = ipipNetUseType;
    }

    public boolean isIpplus360Enable() {
        return ipplus360Enable;
    }

    public void setIpplus360Enable(boolean ipplus360Enable) {
        this.ipplus360Enable = ipplus360Enable;
    }

    public String getIpplus360FingerprintUrl() {
        return ipplus360FingerprintUrl;
    }

    public void setIpplus360FingerprintUrl(String ipplus360FingerprintUrl) {
        this.ipplus360FingerprintUrl = ipplus360FingerprintUrl;
    }

    public String getIpplus360DataUrl() {
        return ipplus360DataUrl;
    }

    public void setIpplus360DataUrl(String ipplus360DataUrl) {
        this.ipplus360DataUrl = ipplus360DataUrl;
    }

    public String getIpplus360FilePath() {
        return ipplus360FilePath;
    }

    public void setIpplus360FilePath(String ipplus360FilePath) {
        this.ipplus360FilePath = ipplus360FilePath;
    }

    public String getIpplus360UseType() {
        return ipplus360UseType;
    }

    public void setIpplus360UseType(String ipplus360UseType) {
        this.ipplus360UseType = ipplus360UseType;
    }

    public boolean isAliyunEnable() {
        return aliyunEnable;
    }

    public void setAliyunEnable(boolean aliyunEnable) {
        this.aliyunEnable = aliyunEnable;
    }

    public String getAliyunRegionId() {
        return aliyunRegionId;
    }

    public void setAliyunRegionId(String aliyunRegionId) {
        this.aliyunRegionId = aliyunRegionId;
    }

    public String getAliyunAccessKeyId() {
        return aliyunAccessKeyId;
    }

    public void setAliyunAccessKeyId(String aliyunAccessKeyId) {
        this.aliyunAccessKeyId = aliyunAccessKeyId;
    }

    public String getAliyunSecret() {
        return aliyunSecret;
    }

    public void setAliyunSecret(String aliyunSecret) {
        this.aliyunSecret = aliyunSecret;
    }

    public String getAliyunInstanceId() {
        return aliyunInstanceId;
    }

    public void setAliyunInstanceId(String aliyunInstanceId) {
        this.aliyunInstanceId = aliyunInstanceId;
    }

    public boolean isAliyunAutoUpgrade() {
        return aliyunAutoUpgrade;
    }

    public void setAliyunAutoUpgrade(boolean aliyunAutoUpgrade) {
        this.aliyunAutoUpgrade = aliyunAutoUpgrade;
    }

    public String getAliyunOssDataInfoUrl() {
        return aliyunOssDataInfoUrl;
    }

    public void setAliyunOssDataInfoUrl(String aliyunOssDataInfoUrl) {
        this.aliyunOssDataInfoUrl = aliyunOssDataInfoUrl;
    }

    public String getAliyunOssDownloadUrl() {
        return aliyunOssDownloadUrl;
    }

    public void setAliyunOssDownloadUrl(String aliyunOssDownloadUrl) {
        this.aliyunOssDownloadUrl = aliyunOssDownloadUrl;
    }

    public Class<? extends DataServer> getAliyunDataServer() {
        return aliyunDataServer;
    }

    public void setAliyunDataServer(Class<? extends DataServer> aliyunDataServer) {
        this.aliyunDataServer = aliyunDataServer;
    }
}
